marktools.get_annotation_attached_to_component
==============================================

.. autofunction:: abjad.tools.marktools.get_annotation_attached_to_component.get_annotation_attached_to_component
